#include "DocumentCommon.h"
#include <OpenGl_GraphicDriver.hxx>

Handle(V3d_Viewer) DocumentCommon::Viewer (const Standard_ExtString theName,
                                           const Standard_CString theDomain,
                                           const Standard_Real theViewSize,
                                           const V3d_TypeOfOrientation theViewProj,
                                           const Standard_Boolean theComputedMode,
                                           const Standard_Boolean theDefaultComputedMode )
{
  static Handle(OpenGl_GraphicDriver) aGraphicDriver;

  if (aGraphicDriver.IsNull())
  {
    Handle(Aspect_DisplayConnection) aDisplayConnection;
#if !defined(_WIN32) && !defined(__WIN32__) && (!defined(__APPLE__) || defined(MACOSX_USE_GLX))
    aDisplayConnection = new Aspect_DisplayConnection (qgetenv ("DISPLAY").constData());
#endif
    aGraphicDriver = new OpenGl_GraphicDriver (aDisplayConnection);
  }

  return new V3d_Viewer (aGraphicDriver,
                         theName,
                         theDomain,
                         theViewSize,
                         theViewProj,
                         Quantity_NOC_GRAY30,
                         V3d_ZBUFFER,
                         V3d_GOURAUD,
                         V3d_WAIT,
                         theComputedMode,
                         theDefaultComputedMode,
                         V3d_TEX_NONE);
}

DocumentCommon::DocumentCommon () {
    TCollection_ExtendedString a3DName ("Visu3D");

     myViewer = Viewer (a3DName.ToExtString(), "", 1000.0, V3d_XposYnegZpos, Standard_True, Standard_True);

     myViewer->SetDefaultLights();
     myViewer->SetLightOn();

     myContext = new AIS_InteractiveContext (myViewer);


}

